#
# spec file for package python-certbot-dns-linode
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-certbot-dns-linode
Version:        2.6.0
Release:        1.3
Summary:        Linode DNS Authenticator plugin for Certbot
License:        Apache-2.0
URL:            https://github.com/certbot/certbot
Source:         https://files.pythonhosted.org/packages/source/c/certbot-dns-linode/certbot-dns-linode-%{version}.tar.gz
BuildRequires:  %{python_module acme >= %{version}}
BuildRequires:  %{python_module certbot >= %{version}}
BuildRequires:  %{python_module dns-lexicon >= 3.2.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-acme >= %{version}
Requires:       python-certbot >= %{version}
Requires:       python-dns-lexicon >= 3.2.1
BuildArch:      noarch
%python_subpackages

%description
This certbot plugin automates the process of completing an ACME
dns-01 challenge by creating, and subsequently removing, TXT
records using Linode's DNS API.

%prep
%setup -q -n certbot-dns-linode-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Wed Jun  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.6.0
  * Support for Python 3.11 was added to Certbot and all of its components.
  * All Certbot components now require pytest to run tests.
  * Packaged tests for all Certbot components besides josepy were moved inside the _internal/tests module.
  * There is now a new Other annotated challenge object to allow plugins to support entirely novel challenges.
* Thu Oct 27 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.31.0
  * sync with the main certbot package
* Wed Sep 21 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.30.0
  * sync with the main certbot package
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.29.0:
  * --allow-subset-of-names will now additionally retry in cases where domains
    are rejected while creating or finalizing orders. This requires subproblem
    support from the ACME server
  * The show_account subcommand now uses the "newAccount" ACME endpoint to
    fetch the account data, so it doesn't rely on the locally stored account URL.
    This fixes situations where Certbot
    would use old ACMEv1 registration info with non-functional account URLs.
  * The generated Certificate Signing Requests are now generated as version 1
    instead of version 3. This resolves situations in where strict enforcement
    of PKCS#10 meant that CSRs that were generated as version 3 were rejected
* Fri Jun 24 2022 Dirk Müller <dmueller@suse.com>
- update to version 1.28.0
  * sync with the main certbot package
* Mon May 30 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.27.0
  * sync with the main certbot package
* Fri Apr  8 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.26.0
  * sync with the main certbot package
* Tue Dec 21 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.22.0
  * sync with the main certbot package
* Tue Aug 10 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.18.0
  * sync with the main certbot package
* Fri Jul 30 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.17.0
  * sync with the main certbot package
* Thu Jul 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Skip building for python 3.6: not all deps are available anymore
  (e.g dns-lexicon).
* Thu Jun 24 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.16.0
  * DNS plugins based on lexicon now require dns-lexicon >= v3.1.0
  * Require the latest certbot and acme plugins for simplicity
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.15.0
  * sync with the main certbot package
* Wed Apr 14 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.14.0
  * sync with the main certbot package
* Mon Mar  8 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.13.0
  * Support for Python 2 has been removed.
* Fri Jan  8 2021 Antonio Larrosa <alarrosa@suse.com>
- update to version 1.11.0
  * sync with the main certbot package
- update to version 1.10.1
  * sync with the main certbot package
- update to version 1.10.0
  * Support for Python 3.9 was added to Certbot and all of its
    components.
* Wed Oct  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.9.0
  * Sync with main certbot package.
* Fri Aug 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.7.0
  * The Linode DNS plugin now waits 120 seconds for DNS propagation, instead of 1200.
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.6.0
  * Sync with main certbot package.
* Thu Jun 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.5.0
  * Sync with main certbot package.
* Thu May 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.4.0
  * Sync with main certbot package.
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.3.0
  * Sync with main certbot package.
* Fri Feb 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.2.0
  * Sync with main certbot package.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.0
  * Sync with main certbot package.
* Fri Jan  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.0
  * Sync with main certbot package.
* Thu Nov 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.40.1
  * Sync with main certbot package.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Oct  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.39.0
  * Support for Python 3.8 was added to Certbot and all of its components.
* Wed Sep 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.38.0
  * sync with main certbot package
* Tue Sep  3 2019 William Brown <william.brown@suse.com>
- Initial commit of 0.37.2
